import { format as d3Format, formatLocale } from 'd3-format';
import { isRequired } from '@superset-ui/core';
import NumberFormatter from '../NumberFormatter';
export default function createD3NumberFormatter(config) {
  const {
    description,
    formatString = isRequired('config.formatString'),
    label,
    locale
  } = config;
  let formatFunc;
  let isInvalid = false;

  try {
    formatFunc = typeof locale === 'undefined' ? d3Format(formatString) : formatLocale(locale).format(formatString);
  } catch (error) {
    formatFunc = value => value + " (Invalid format: " + formatString + ")";

    isInvalid = true;
  }

  return new NumberFormatter({
    description,
    formatFunc,
    id: formatString,
    isInvalid,
    label
  });
}